#
# spec file for package perl-Digest-MD4
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Digest-MD4
Name:           perl-Digest-MD4
Version:        1.900.0
Release:        1.1
# 1.9 -> normalize -> 1.900.0
%define cpan_version 1.9
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl interface to the MD4 Algorithm
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIKEM/DigestMD4/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Digest::MD4) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The 'Digest::MD4' module allows you to use the RSA Data Security Inc. MD4
Message Digest algorithm from within Perl programs. The algorithm takes as
input a message of arbitrary length and produces as output a 128-bit
"fingerprint" or "message digest" of the input.

The 'Digest::MD4' module provide a procedural interface for simple use, as
well as an object oriented interface that can handle messages of arbitrary
length and which can read files directly.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README rfc1320.txt

%changelog
* Thu Feb  6 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.9
  Fixed example output in doc in MD4.pm. Reported by jbwaters@gmail.com.
  Removed defunct code that caused incorrect error message when building on 64 bit platforms, patch by
  Fixed a test error in files.t. Corrected the comment to do with the reason in
  Updated author and distribution location details to airspayce.com
* Tue Mar  6 2012 andrea.turrini@gmail.com
- fixed typo in perl-Digest-MD4.spec description
* Fri Nov 18 2011 coolo@suse.com
- regenerate with cpanspec 1.78.05
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul 29 2005 mjancar@suse.cz
- update to 1.5
* Fri Feb 27 2004 mjancar@suse.cz
- update to 1.3
* Fri Oct 31 2003 schwab@suse.de
- Fix syntax error.
* Thu Oct 30 2003 mjancar@suse.cz
- update to 1.2
- no root for build
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Thu Jun 19 2003 mjancar@suse.cz
- use $RPM_OPT_FLAGS
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Thu Jan 17 2002 garloff@suse.de
- Initial creation of package perl-Digest-MD4 (version 1.1)
  (Needed for InterMezzo)
